==> gcc-java-4.7.1-i486-1.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libgcj_bc.so.1 )
( cd usr/lib ; ln -sf libgcj_bc.so.1.0.0 libgcj_bc.so.1 )
( cd usr/lib ; rm -rf libgcj-tools.so.13 )
( cd usr/lib ; ln -sf libgcj-tools.so.13.0.0 libgcj-tools.so.13 )
( cd usr/lib ; rm -rf libgij.so.13 )
( cd usr/lib ; ln -sf libgij.so.13.0.0 libgij.so.13 )
( cd usr/lib ; rm -rf libgcj.so )
( cd usr/lib ; ln -sf libgcj.so.13.0.0 libgcj.so )
( cd usr/lib/jvm/jre/lib ; rm -rf rt.jar )
( cd usr/lib/jvm/jre/lib ; ln -sf ../../../../share/java/libgcj-4.7.1.jar rt.jar )
( cd usr/lib/jvm/jre/lib/i386/client ; rm -rf libjvm.so )
( cd usr/lib/jvm/jre/lib/i386/client ; ln -sf ../../../../../gcj-4.7.1-13/libjvm.so libjvm.so )
( cd usr/lib/jvm/jre/lib/i386/server ; rm -rf libjvm.so )
( cd usr/lib/jvm/jre/lib/i386/server ; ln -sf ../../../../../gcj-4.7.1-13/libjvm.so libjvm.so )
( cd usr/lib/jvm/jre/lib/i386 ; rm -rf libjawt.so )
( cd usr/lib/jvm/jre/lib/i386 ; ln -sf ../../../../gcj-4.7.1-13/libjawt.so libjawt.so )
( cd usr/lib/jvm/jre/lib/security ; rm -rf java.security )
( cd usr/lib/jvm/jre/lib/security ; ln -sf ../../../../security/classpath.security java.security )
( cd usr/lib/jvm/jre/bin ; rm -rf tnameserv )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/gtnameserv tnameserv )
( cd usr/lib/jvm/jre/bin ; rm -rf rmid )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/grmid rmid )
( cd usr/lib/jvm/jre/bin ; rm -rf orbd )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/gorbd orbd )
( cd usr/lib/jvm/jre/bin ; rm -rf rmiregistry )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/grmiregistry rmiregistry )
( cd usr/lib/jvm/jre/bin ; rm -rf java )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/gij java )
( cd usr/lib/jvm/jre/bin ; rm -rf keytool )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/gkeytool keytool )
( cd usr/lib/jvm/lib ; rm -rf tools.jar )
( cd usr/lib/jvm/lib ; ln -sf ../../../share/java/libgcj-tools-4.7.1.jar tools.jar )
( cd usr/lib/jvm/bin ; rm -rf tnameserv )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gtnameserv tnameserv )
( cd usr/lib/jvm/bin ; rm -rf native2ascii )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gnative2ascii native2ascii )
( cd usr/lib/jvm/bin ; rm -rf serialver )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gserialver serialver )
( cd usr/lib/jvm/bin ; rm -rf rmid )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/grmid rmid )
( cd usr/lib/jvm/bin ; rm -rf jarsigner )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gjarsigner jarsigner )
( cd usr/lib/jvm/bin ; rm -rf rmic )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/grmic rmic )
( cd usr/lib/jvm/bin ; rm -rf appletviewer )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gappletviewer appletviewer )
( cd usr/lib/jvm/bin ; rm -rf javah )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gjavah javah )
( cd usr/lib/jvm/bin ; rm -rf javac )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/ecj javac )
( cd usr/lib/jvm/bin ; rm -rf orbd )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gorbd orbd )
( cd usr/lib/jvm/bin ; rm -rf jar )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gjar jar )
( cd usr/lib/jvm/bin ; rm -rf rmiregistry )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/grmiregistry rmiregistry )
( cd usr/lib/jvm/bin ; rm -rf java )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gij java )
( cd usr/lib/jvm/bin ; rm -rf keytool )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gkeytool keytool )
( cd usr/lib/jvm/bin ; rm -rf javadoc )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gjdoc javadoc )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-rmi-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-rmi-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-ldap.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-ldap-1.5.0.0.jar jndi-ldap.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jsse-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jsse-1.5.0.0.jar jsse-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jce-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jce-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-1.5.0.0.jar jndi-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jaas-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jaas-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jce.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jce-1.5.0.0.jar jce.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-dns.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-dns-1.5.0.0.jar jndi-dns.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-dns-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-dns-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-1.5.0.0.jar jndi.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-dns-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-dns-1.5.0.0.jar jndi-dns-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf sasl-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf sasl-1.5.0.0.jar sasl-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jsse.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jsse-1.5.0.0.jar jsse.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jdbc-stdext.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jdbc-stdext-1.5.0.0.jar jdbc-stdext.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-ldap-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-ldap-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-cos-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-cos-1.5.0.0.jar jndi-cos-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf sasl-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar sasl-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf sasl.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf sasl-1.5.0.0.jar sasl.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jdbc-stdext-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jdbc-stdext-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-cos-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-cos-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-rmi-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-rmi-1.5.0.0.jar jndi-rmi-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-ldap-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-ldap-1.5.0.0.jar jndi-ldap-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jce-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jce-1.5.0.0.jar jce-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jaas-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jaas-1.5.0.0.jar jaas-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-cos.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-cos-1.5.0.0.jar jndi-cos.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-rmi.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-rmi-1.5.0.0.jar jndi-rmi.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jaas.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jaas-1.5.0.0.jar jaas.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jsse-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jsse-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jdbc-stdext-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jdbc-stdext-1.5.0.0.jar jdbc-stdext-1.5.0.jar )
( cd usr/lib/jvm/include/linux ; rm -rf jawt_md.h )
( cd usr/lib/jvm/include/linux ; ln -sf ../../../../bin/../lib/gcc/i486-slackware-linux/4.7.1/include/jawt_md.h jawt_md.h )
( cd usr/lib/jvm/include/linux ; rm -rf jni_md.h )
( cd usr/lib/jvm/include/linux ; ln -sf ../../../../bin/../lib/gcc/i486-slackware-linux/4.7.1/include/jni_md.h jni_md.h )
( cd usr/lib/jvm/include ; rm -rf jawt.h )
( cd usr/lib/jvm/include ; ln -sf ../../../bin/../lib/gcc/i486-slackware-linux/4.7.1/include/jawt.h jawt.h )
( cd usr/lib/jvm/include ; rm -rf jni.h )
( cd usr/lib/jvm/include ; ln -sf ../../../bin/../lib/gcc/i486-slackware-linux/4.7.1/include/jni.h jni.h )
( cd usr/lib ; rm -rf libgcj.so.13 )
( cd usr/lib ; ln -sf libgcj.so.13.0.0 libgcj.so.13 )
( cd usr/lib ; rm -rf libgij.so )
( cd usr/lib ; ln -sf libgij.so.13.0.0 libgij.so )
( cd usr/lib ; rm -rf libgcj-tools.so )
( cd usr/lib ; ln -sf libgcj-tools.so.13.0.0 libgcj-tools.so )
( cd usr/bin ; rm -rf i486-slackware-linux-gcjh )
( cd usr/bin ; ln -sf gcjh i486-slackware-linux-gcjh )
( cd usr/bin ; rm -rf i486-slackware-linux-gcj )
( cd usr/bin ; ln -sf gcj i486-slackware-linux-gcj )

==> gcc-java-4.8.2-i486-1.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libgcj.so )
( cd usr/lib ; ln -sf libgcj.so.14.0.0 libgcj.so )
( cd usr/lib ; rm -rf libgij.so.14 )
( cd usr/lib ; ln -sf libgij.so.14.0.0 libgij.so.14 )
( cd usr/lib ; rm -rf libgij.so )
( cd usr/lib ; ln -sf libgij.so.14.0.0 libgij.so )
( cd usr/lib ; rm -rf libgcj.so.14 )
( cd usr/lib ; ln -sf libgcj.so.14.0.0 libgcj.so.14 )
( cd usr/lib/jvm/lib ; rm -rf tools.jar )
( cd usr/lib/jvm/lib ; ln -sf ../../../share/java/libgcj-tools-4.8.2.jar tools.jar )
( cd usr/lib/jvm/bin ; rm -rf keytool )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gkeytool keytool )
( cd usr/lib/jvm/bin ; rm -rf serialver )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gserialver serialver )
( cd usr/lib/jvm/bin ; rm -rf jarsigner )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gjarsigner jarsigner )
( cd usr/lib/jvm/bin ; rm -rf orbd )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gorbd orbd )
( cd usr/lib/jvm/bin ; rm -rf rmic )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/grmic rmic )
( cd usr/lib/jvm/bin ; rm -rf appletviewer )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gappletviewer appletviewer )
( cd usr/lib/jvm/bin ; rm -rf jar )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gjar jar )
( cd usr/lib/jvm/bin ; rm -rf rmid )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/grmid rmid )
( cd usr/lib/jvm/bin ; rm -rf javah )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gjavah javah )
( cd usr/lib/jvm/bin ; rm -rf javadoc )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gjdoc javadoc )
( cd usr/lib/jvm/bin ; rm -rf java )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gij java )
( cd usr/lib/jvm/bin ; rm -rf native2ascii )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gnative2ascii native2ascii )
( cd usr/lib/jvm/bin ; rm -rf javac )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/ecj javac )
( cd usr/lib/jvm/bin ; rm -rf rmiregistry )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/grmiregistry rmiregistry )
( cd usr/lib/jvm/bin ; rm -rf tnameserv )
( cd usr/lib/jvm/bin ; ln -sf ../../../bin/gtnameserv tnameserv )
( cd usr/lib/jvm/jvm-exports ; rm -rf sasl-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf sasl-1.5.0.0.jar sasl-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-ldap-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-ldap-1.5.0.0.jar jndi-ldap-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-rmi.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-rmi-1.5.0.0.jar jndi-rmi.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jdbc-stdext-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jdbc-stdext-1.5.0.0.jar jdbc-stdext-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-ldap.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-ldap-1.5.0.0.jar jndi-ldap.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-dns-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-dns-1.5.0.0.jar jndi-dns-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jaas.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jaas-1.5.0.0.jar jaas.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jsse.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jsse-1.5.0.0.jar jsse.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jsse-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jsse-1.5.0.0.jar jsse-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-rmi-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-rmi-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jdbc-stdext.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jdbc-stdext-1.5.0.0.jar jdbc-stdext.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jaas-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jaas-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf sasl-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar sasl-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-ldap-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-ldap-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jsse-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jsse-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf sasl.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf sasl-1.5.0.0.jar sasl.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-cos-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-cos-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-cos.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-cos-1.5.0.0.jar jndi-cos.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jce-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jce-1.5.0.0.jar jce-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-1.5.0.0.jar jndi-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jce-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jce-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-dns-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jndi-dns-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-cos-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-cos-1.5.0.0.jar jndi-cos-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-rmi-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-rmi-1.5.0.0.jar jndi-rmi-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jaas-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jaas-1.5.0.0.jar jaas-1.5.0.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jce.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jce-1.5.0.0.jar jce.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi-dns.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-dns-1.5.0.0.jar jndi-dns.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jndi.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf jndi-1.5.0.0.jar jndi.jar )
( cd usr/lib/jvm/jvm-exports ; rm -rf jdbc-stdext-1.5.0.0.jar )
( cd usr/lib/jvm/jvm-exports ; ln -sf ../jre/lib/rt.jar jdbc-stdext-1.5.0.0.jar )
( cd usr/lib/jvm/jre/lib/i386/server ; rm -rf libjvm.so )
( cd usr/lib/jvm/jre/lib/i386/server ; ln -sf ../../../../../gcj-4.8.2-14/libjvm.so libjvm.so )
( cd usr/lib/jvm/jre/lib/i386/client ; rm -rf libjvm.so )
( cd usr/lib/jvm/jre/lib/i386/client ; ln -sf ../../../../../gcj-4.8.2-14/libjvm.so libjvm.so )
( cd usr/lib/jvm/jre/lib/i386 ; rm -rf libjawt.so )
( cd usr/lib/jvm/jre/lib/i386 ; ln -sf ../../../../gcj-4.8.2-14/libjawt.so libjawt.so )
( cd usr/lib/jvm/jre/lib/security ; rm -rf java.security )
( cd usr/lib/jvm/jre/lib/security ; ln -sf ../../../../security/classpath.security java.security )
( cd usr/lib/jvm/jre/lib ; rm -rf rt.jar )
( cd usr/lib/jvm/jre/lib ; ln -sf ../../../../share/java/libgcj-4.8.2.jar rt.jar )
( cd usr/lib/jvm/jre/bin ; rm -rf keytool )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/gkeytool keytool )
( cd usr/lib/jvm/jre/bin ; rm -rf orbd )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/gorbd orbd )
( cd usr/lib/jvm/jre/bin ; rm -rf rmid )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/grmid rmid )
( cd usr/lib/jvm/jre/bin ; rm -rf java )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/gij java )
( cd usr/lib/jvm/jre/bin ; rm -rf rmiregistry )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/grmiregistry rmiregistry )
( cd usr/lib/jvm/jre/bin ; rm -rf tnameserv )
( cd usr/lib/jvm/jre/bin ; ln -sf ../../../../bin/gtnameserv tnameserv )
( cd usr/lib/jvm/include ; rm -rf jni.h )
( cd usr/lib/jvm/include ; ln -sf ../../../bin/../lib/gcc/i486-slackware-linux/4.8.2/include/jni.h jni.h )
( cd usr/lib/jvm/include/linux ; rm -rf jawt_md.h )
( cd usr/lib/jvm/include/linux ; ln -sf ../../../../bin/../lib/gcc/i486-slackware-linux/4.8.2/include/jawt_md.h jawt_md.h )
( cd usr/lib/jvm/include/linux ; rm -rf jni_md.h )
( cd usr/lib/jvm/include/linux ; ln -sf ../../../../bin/../lib/gcc/i486-slackware-linux/4.8.2/include/jni_md.h jni_md.h )
( cd usr/lib/jvm/include ; rm -rf jawt.h )
( cd usr/lib/jvm/include ; ln -sf ../../../bin/../lib/gcc/i486-slackware-linux/4.8.2/include/jawt.h jawt.h )
( cd usr/lib ; rm -rf libgcj-tools.so.14 )
( cd usr/lib ; ln -sf libgcj-tools.so.14.0.0 libgcj-tools.so.14 )
( cd usr/lib ; rm -rf libgcj-tools.so )
( cd usr/lib ; ln -sf libgcj-tools.so.14.0.0 libgcj-tools.so )
( cd usr/lib ; rm -rf libgcj_bc.so.1 )
( cd usr/lib ; ln -sf libgcj_bc.so.1.0.0 libgcj_bc.so.1 )
( cd usr/bin ; rm -rf i486-slackware-linux-gcj )
( cd usr/bin ; ln -sf gcj i486-slackware-linux-gcj )
( cd usr/bin ; rm -rf i486-slackware-linux-gcjh )
( cd usr/bin ; ln -sf gcjh i486-slackware-linux-gcjh )
